rename BroadcastStrategy to MulticastStrategy

refs #3011

Change-Id: I53c0f4ad4b11c4438765cb697bdabf678d83b8e3
diff --git a/test_nfdc/README.md b/test_nfdc/README.md
index 5803770..1c8ea51 100644
--- a/test_nfdc/README.md
+++ b/test_nfdc/README.md
@@ -37,7 +37,7 @@
 12. Invoke nfdc to add a nexthop for ndn:/test-nfdc with cost 14 toward FaceId created in step 7.
 13. Invoke nfdc to add a nexthop for ndn:/test-nfdc with cost 16 toward FaceId created in step 9.
 14. Execute nfd-status. Check the existence of ndn:/test-nfdc FIB entry, and the correctness of cost on nexthop records.
-15. Invoke nfdc to choose BroadcastStrategy for ndn:/ namespace.
+15. Invoke nfdc to choose MulticastStrategy for ndn:/ namespace.
 16. Invoke ndnping to send 100 Interests under ndn:/test-nfdc prefix.
 17. Pause 50ms before sending each Interest.
 18. Execute nfd-status. Verify NOutInterests counters of faces created in step 3,5,7,9 are greater than 60.
diff --git a/test_nfdc/nfdc-test.sh b/test_nfdc/nfdc-test.sh
index daa76da..fcaecc0 100755
--- a/test_nfdc/nfdc-test.sh
+++ b/test_nfdc/nfdc-test.sh
@@ -86,8 +86,8 @@
   # check correctness of add-nexthop -c 16 ndn:/test-nfdc $faceIdUdp6
   check_nfd_status_correctness $faceIdUdp6 udp6://[$IP6_B1] /test-nfdc 16
 
-  # Invoke nfdc to choose BroadcastStrategy for ndn:/ namespace.
-  nfdc set-strategy ndn:/ ndn:/localhost/nfd/strategy/broadcast
+  # Invoke nfdc to choose MulticastStrategy for ndn:/ namespace.
+  nfdc set-strategy ndn:/ ndn:/localhost/nfd/strategy/multicast
 
   ndnping -c $NUM_OF_PINGS ndn:/test-nfdc